@@ -1168,10 +1168,20 @@ if_eval_locktoken(Target,Token,[H|T]) ->
 
 -define(CONTENT(X), X#xmlElement.content).
 
+%% Reject attempts to fetch external reesources in order to guard
+%% against XXE attacks
+fetch_resource(_Res, State) ->
+    {ok, not_fetched, State}.
+
+%% TODO convert this to use xmerl_sax_parser instead
+parse_xml(XML) ->
+    xmerl_scan:string(XML, [{namespace_conformant, true},
+                            {fetch_fun, fun fetch_resource/2}]).
+
 %% Parameter is always list
 parse_propfind([]) -> [allprop]; % RFC4918: no body then allprop, is [] no body?
 parse_propfind(L) ->
-    case catch xmerl_scan:string(L, [{namespace_conformant, true}]) of
+    case catch parse_xml(L) of
         {?IS_PROPFIND(X),_} ->
             parse_propfind(?CONTENT(X),[]);
         _Z ->
@@ -1192,7 +1202,7 @@ parse_propfind([], R) ->
     R.
 
 parse_proppatch(L) ->
-    case catch xmerl_scan:string(L, [{namespace_conformant, true}]) of
+    case catch parse_xml(L) of
         {?IS_PROPERTYUPDATE(X),_} ->
             parse_proppatch(?CONTENT(X),[]);
         _Z ->
@@ -1241,7 +1251,7 @@ parse_prop([], L) ->
 parse_lockinfo([]) ->
     #lock{};
 parse_lockinfo(L) ->
-    case catch xmerl_scan:string(L, [{namespace_conformant, true}]) of
+    case catch parse_xml(L) of
         {?IS_LOCKINFO(X),_} ->
             parse_lockinfo(?CONTENT(X),#lock{});
         _Z ->
